@@ -8,8 +8,12 @@ partitioned by (
   `{{ column.target_column }}` varchar(65535){{ "," if not loop.last }}
 {% endfor %}
 )
+{% if source_format == 'json' %}
+row format serde 'org.openx.data.jsonserde.JsonSerDe'
+{% else %}
 row format delimited
   fields terminated by '{{ field_delimiter }}'
+{% endif %}
 stored as inputformat
   'org.apache.hadoop.mapred.TextInputFormat'
 outputformat
@@ -18,9 +22,11 @@ location
   '{{ source_location }}'
 tblproperties (
   'arecolumnsquoted'='false',
-  'classification'='csv',
+  'classification'='{{ source_format }}',
   'columnsordered'='true',
-  'compressiontype'='none',
+  'compressionType'='{{ compression_type or 'none' }}',
+{%- if source_format != 'json' -%}
   'delimiter'='{{ field_delimiter }}',
-  'typeofdata'='file'
+{%- endif %}
+  'typeOfData'='file'
 );
